@@ -4,7 +4,7 @@ class JudiStandardMixin:
     def common_message_tree(self):
         return {
             'update': {
-                'device_info': self.handshake_recieved
+                'device_info': self.handshake_received
             },
             'response': {
                 'ok': None, 
@@ -18,7 +18,7 @@ class JudiStandardMixin:
     def handshake(self):
         self.send({'request':'device_info'})
 
-    def handshake_recieved(self, response):
+    def handshake_received(self, response):
         if 'product_name' in response:
             self.name = response['product_name']
         if 'serial_number' in response:
@@ -28,8 +28,8 @@ class JudiStandardMixin:
         if 'protocol_version' in response:
             self.protocol_version = response['protocol_version']
 
-        if hasattr(self, 'signals') and hasattr(self.signals, 'handshake_recieved'):
-            self.signals.handshake_recieved.emit(response)
+        if hasattr(self, 'signals') and hasattr(self.signals, 'handshake_received'):
+            self.signals.handshake_received.emit(response)
 
     def locate(self):
         self.send({'command':'locate'})
\ No newline at end of file
